@@ -15,7 +15,7 @@
 This module provides management interface components.
 """
 
-from pyams_auth_sql.interfaces import ISQLAuthPlugin
+from pyams_auth_sql.interfaces import ISQLAuthPlugin, SQL_AUTH_PLUGIN_LABEL
 from pyams_form.ajax import ajax_form_config
 from pyams_layer.interfaces import IPyAMSLayer
 from pyams_pagelet.pagelet import pagelet_config
@@ -24,10 +24,10 @@ from pyams_security.interfaces.base import MANAGE_SECURITY_PERMISSION
 from pyams_security_views.zmi import SecurityPluginsTable
 from pyams_security_views.zmi.plugin import SecurityPluginAddForm, SecurityPluginAddMenu, \
     SecurityPluginPropertiesEditForm
-from pyams_site.interfaces import ISiteRoot
 from pyams_table.column import GetAttrColumn
 from pyams_table.interfaces import IColumn, IValues
 from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
+from pyams_utils.registry import get_utility
 from pyams_utils.url import absolute_url
 from pyams_viewlet.viewlet import viewlet_config
 from pyams_zmi.interfaces import IAdminLayer
@@ -42,8 +42,8 @@ from pyams_auth_sql import _  # pylint: disable=ungrouped-imports
 
 
 @viewlet_config(name='add-sql-auth-plugin.menu',
-                context=ISiteRoot, layer=IAdminLayer, view=SecurityPluginsTable,
-                manager=IContextAddingsViewletManager, weight=70,
+                context=ISecurityManager, layer=IAdminLayer, view=SecurityPluginsTable,
+                manager=IContextAddingsViewletManager, weight=50,
                 permission=MANAGE_SECURITY_PERMISSION)
 class SQLAuthPluginAddMenu(SecurityPluginAddMenu):
     """SQL authentication plug-in add menu"""
@@ -58,15 +58,14 @@ class SQLAuthPluginAddMenu(SecurityPluginAddMenu):
 class SQLAuthPluginAddForm(SecurityPluginAddForm):
     """SQL authentication plug-in add form"""
 
-    legend = _("Add SQL authentication plug-in")
     content_factory = ISQLAuthPlugin
+    content_label = SQL_AUTH_PLUGIN_LABEL
 
 
 @ajax_form_config(name='properties.html', context=ISQLAuthPlugin, layer=IPyAMSLayer)
 class SQLAuthPluginPropertiesEditForm(SecurityPluginPropertiesEditForm):
     """SQL authentication plug-in properties edit form"""
 
-    title = _("SQL authentication plug-in")
     plugin_interface = ISQLAuthPlugin
 
 
@@ -82,7 +81,8 @@ class SQLAuthPluginSearchForm(SearchForm):  # pylint: disable=abstract-method
     @property
     def back_url(self):
         """Form back URL getter"""
-        return absolute_url(self.request.root, self.request, 'security-plugins.html')
+        manager = get_utility(ISecurityManager)
+        return absolute_url(manager, self.request, 'security-plugins.html')
 
 
 @pagelet_config(name='search.html', context=ISQLAuthPlugin, layer=IPyAMSLayer,
